@@ -1,7 +1,7 @@
 package Complete::File;
 
-our $DATE = '2016-10-19'; # DATE
-our $VERSION = '0.41'; # VERSION
+our $DATE = '2016-10-20'; # DATE
+our $VERSION = '0.42'; # VERSION
 
 use 5.010001;
 use strict;
@@ -268,6 +268,7 @@ $SPEC{complete_dir} = do {
 
     $spec->{summary} = 'Complete directory from local filesystem '.
         '(wrapper for complete_dir() that only picks directories)';
+    $spec->{args} = { %{$spec->{args}} }; # shallow copy of args
     delete $spec->{args}{file_regex_filter};
     delete $spec->{args}{file_ext_filter};
     delete $spec->{args}{exclude_dir};
@@ -295,7 +296,7 @@ Complete::File - Completion routines related to files
 
 =head1 VERSION
 
-This document describes version 0.41 of Complete::File (from Perl distribution Complete-File), released on 2016-10-19.
+This document describes version 0.42 of Complete::File (from Perl distribution Complete-File), released on 2016-10-20.
 
 =head1 DESCRIPTION
 
@@ -366,6 +367,27 @@ If turned off, will not allow "." or ".." in path.
 This is most useful when combined with C<starting_path> option to prevent user
 going up/outside the starting path.
 
+=item * B<exclude_dir> => I<bool>
+
+This is also an alternative to specifying full C<filter>. Set this to true if you
+do not want directories.
+
+If you only want directories, take a look at C<complete_dir()>.
+
+=item * B<file_ext_filter> => I<re|array[str]>
+
+This is also an alternative to specifying full C<filter> or C<file_regex_filter>.
+You can set this to a regex or a set of extensions to accept. Note that like in
+C<file_regex_filter>, directories of any name is also still allowed.
+
+=item * B<file_regex_filter> => I<re>
+
+Filter shortcut for file regex.
+
+This is a shortcut for constructing a filter. So instead of using C<filter>, you
+use this option. This will construct a filter of including only directories or
+regular files, and the file must match a regex pattern. This use-case is common.
+
 =item * B<filter> => I<str|code>
 
 Only return items matching this filter.
